Package: regioneReloaded
Type: Package
Title: RegioneReloaded: Multiple Association for Genomic Region Sets
Version: 1.15.0
Authors@R: c(
    person(given = "Roberto",
           family = "Malinverni",
           role = c("aut", "cre"),
           email = "roberto.malinverni@gmail.com",
           comment = c(ORCID ="0000-0002-0113-3417")),
    person(given = "David",
           family = "Corujo",
           role = c("aut"),
           email = "dcorujo@carrerasresearch.org"),
    person(given = "Bernat",
           family = "Gel",
           role = c("aut"),
           email = "bgel@igtp.org"))
URL: https://github.com/RMalinverni/regioneReload
Description: RegioneReloaded is a package that allows simultaneous analysis of associations between genomic region sets, enabling clustering of data and the creation of ready-to-publish graphs. It takes over and expands on all the features of its predecessor regioneR. It also incorporates a strategy to improve p-value calculations and normalize z-scores coming from multiple analysis to allow for their direct comparison. RegioneReloaded builds upon regioneR by adding new plotting functions for obtaining publication-ready graphs. 
License: Artistic-2.0
Encoding: UTF-8
LazyData: false
RoxygenNote: 7.2.1
Roxygen: list(markdown = TRUE)
Depends: R (>= 4.2), regioneR
Imports: stats, RColorBrewer, Rtsne, umap, ggplot2, ggrepel, reshape2,
        methods, scales, cluster, grid, grDevices
Suggests: rmarkdown, BiocStyle, GenomeInfoDb, knitr, testthat (>=
        3.0.0)
biocViews: Genetics, ChIPSeq, DNASeq, MethylSeq, CopyNumberVariation,
        Clustering, MultipleComparison
VignetteBuilder: knitr
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/regioneReloaded
git_branch: devel
git_last_commit: d229c87
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 00:38:04 UTC; biocbuild
Author: Roberto Malinverni [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-0113-3417>),
  David Corujo [aut],
  Bernat Gel [aut]
Maintainer: Roberto Malinverni <roberto.malinverni@gmail.com>
