# getParameters retrieves the correct data

    Code
      getParameters(cw_Alien_ReG)
    Output
             parameter              value
      1          Alist AlienRSList_narrow
      2          Blist AlienRSList_narrow
      3       sampling              FALSE
      4       fraction               0.15
      5   min_sampling               0.15
      6         ranFUN     resampleGenome
      7          evFUN        numOverlaps
      8         ntimes               1000
      9       universe               NULL
      10 adj_pv_method                 BH
      11            nc               NULL
      12      matOrder               NULL

---

    Code
      getParameters(mLZ_regA_ReG)
    Output
             parameter                   value
      1              A AlienRSList_narrow$regA
      2          Blist      AlienRSList_narrow
      3       sampling                   FALSE
      4       fraction                    0.15
      5   min_sampling                    0.15
      6         ranFUN          resampleGenome
      7          evFUN             numOverlaps
      8       universe                    NULL
      9         window                     600
      10          step                      10
      11 adj_pv_method                      BH
      12        max_pv                    0.05
      13      Nregions                     100

