% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getHClust.R
\name{getHClust}
\alias{getHClust}
\title{getHClust}
\usage{
getHClust( rR, hctype = "rows")
}
\arguments{
\item{rR}{A genoMatriXeR or multiLocalZScore object.}

\item{hctype}{character. Can be "rows" or "cols". (default= "cols")}
}
\value{
an object of class \link{hclust}
}
\description{
get Object of class \link{hclust} from  \link[=genoMatriXeR-class]{genoMatriXeR} or \link[=multiLocalZScore-class]{multiLocalZScore}
}
\examples{

data("cw_Alien")

cw_Alien_ReG <- makeCrosswiseMatrix(cw_Alien_ReG)
hc <- getHClust(cw_Alien_ReG)

plot(hc)

}
\seealso{
\link[=genoMatriXeR-class]{genoMatriXeR}, \link[=multiLocalZScore-class]{multiLocalZScore}, \link{hclust}
}
